import numpy as np
import pandas as pd
import sys
import os
import argparse
import simtk.unit as unit
import simtk.openmm
import simtk.openmm.app as app
from openmmplumed import PlumedForce

parser = argparse.ArgumentParser()
parser.add_argument('--platform', default='CPU', choices=['Reference', 'CPU', 'CUDA', 'OpenCL'], help='platform name')
args = parser.parse_args()

system = simtk.openmm.XmlSerializer.deserialize(open('system.xml').read())
state = simtk.openmm.XmlSerializer.deserialize(open('state.xml').read())

pdb = 'cg_nucl.pdb'
top = app.PDBFile(pdb).getTopology()

with open('plumed.txt', 'r') as input_reader:
    system.addForce(PlumedForce(input_reader.read()))

temp = 300*unit.kelvin
collision = 1/unit.picosecond
timestep = 10*unit.femtosecond
integrator = simtk.openmm.NoseHooverIntegrator(temp, collision, timestep)
platform = simtk.openmm.Platform.getPlatformByName(args.platform)
if args.platform in ['CUDA', 'OpenCL']:
    simulation = app.Simulation(top, system, integrator, platform, {'Precision': 'mixed'})
else:
    simulation = app.Simulation(top, system, integrator, platform)
simulation.context.setState(state)
simulation.minimizeEnergy()
simulation.context.setVelocitiesToTemperature(temp)
simulation.step(100)


